# -*- coding: utf-8 -*-

# This file is part of the Gedit LaTeX Plugin
#
# Copyright (C) 2006 Michael Zeising
#
# This program is free software; you can redistribute it and/or modify it under
# the terms of the GNU General Public Licence as published by the Free Software
# Foundation; either version 2 of the Licence, or (at your option) any later
# version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU General Public Licence for more 
# details.
#
# You should have received a copy of the GNU General Public Licence along with
# this program; if not, write to the Free Software Foundation, Inc., 51 Franklin
# Street, Fifth Floor, Boston, MA  02110-1301, USA

from common import Profile
from gtk import Dialog, DIALOG_MODAL, DIALOG_DESTROY_WITH_PARENT, STOCK_CANCEL, RESPONSE_CANCEL, STOCK_OK, RESPONSE_OK, \
	Entry, Label, Button, STOCK_ADD, ListStore, TreeView, CellRendererText, ScrolledWindow, POLICY_AUTOMATIC, SHADOW_IN, \
	STOCK_GO_UP, STOCK_GO_DOWN, STOCK_DELETE, VButtonBox, BUTTONBOX_START, Table, EXPAND, FILL, combo_box_entry_new_text

class ProfileDialog (Dialog):
	"""
	The dialog for configuring or adding a custom build profile
	"""
	def __init__(self):
		Dialog.__init__(self, "", None, DIALOG_MODAL | DIALOG_DESTROY_WITH_PARENT, (STOCK_CANCEL, RESPONSE_CANCEL, STOCK_OK, RESPONSE_OK))
		
		self.set_border_width(5)
		self.set_has_separator(False)
		self.vbox.set_spacing(10)
		
		## name
		self.entry_name = Entry()
		
		lbl_name = Label()
		lbl_name.set_markup("<b>_Name</b>")
		lbl_name.set_alignment(0, .5)
		lbl_name.set_use_underline(True)
		lbl_name.set_mnemonic_widget(self.entry_name)
		
		## commands
		lbl_info = Label("<small><b>%f</b>\tFilename\n<b>%e</b>\tFilename without .tex suffix\n<b>%p</b>\tDirectory of the LaTeX plugin</small>")
		lbl_info.set_use_markup(True)
		lbl_info.set_alignment(0, .5)
		
		self.cmb_command = combo_box_entry_new_text()
		for item in ["latex -interaction batchmode -file-line-error %f", "dvipdf %e.dvi"]:
			self.cmb_command.append_text(item)
		
		lbl_commands = Label()
		lbl_commands.set_markup("<b>_Command(s)</b>")
		lbl_commands.set_alignment(0, .5)
		lbl_commands.set_use_underline(True)
		lbl_commands.set_mnemonic_widget(self.cmb_command)
		
		btn_add = Button(stock=STOCK_ADD)
		btn_add.connect("clicked", lambda x: self.__add_command())
		
		self.store_commands = ListStore(str)
		
		self.view_commands = TreeView(self.store_commands)
		self.view_commands.set_headers_visible(False)
		self.view_commands.insert_column_with_attributes(-1, "", CellRendererText(), markup=0)
		
		scr_commands = ScrolledWindow()
		scr_commands.set_policy(POLICY_AUTOMATIC, POLICY_AUTOMATIC);
		scr_commands.set_shadow_type(SHADOW_IN)
		scr_commands.add(self.view_commands)
		
		btn_down = Button(stock=STOCK_GO_DOWN)
		btn_down.connect("clicked", lambda x: self.__move_down_command())
		
		btn_delete = Button(stock=STOCK_DELETE)
		btn_delete.connect("clicked", lambda x: self.__delete_command())
		
		buttons = VButtonBox()
		buttons.set_layout(BUTTONBOX_START)
		buttons.pack_start(btn_down)
		buttons.pack_start(btn_delete)
		
		## view command
		self.entry_view_command = Entry()
		
		lbl_view = Label()
		lbl_view.set_markup("<b>_Viewing Command</b>")
		lbl_view.set_alignment(0, .5)
		lbl_view.set_use_underline(True)
		lbl_view.set_mnemonic_widget(self.entry_view_command)
		
		## accelerator
		self.entry_accel = Entry()
		
		lbl_accel = Label()
		lbl_accel.set_markup("<b>Accelerator</b>")
		lbl_accel.set_alignment(0, .5)
		lbl_accel.set_use_underline(True)
		lbl_accel.set_mnemonic_widget(self.entry_accel)
		
		lbl_accel_info = Label()
		lbl_accel_info.set_markup("<small>An accelerator like <b>&lt;Shift&gt;&lt;Alt&gt;F1</b> or <b>&lt;Control&gt;a</b></small>")
		lbl_accel_info.set_alignment(0, .5)
		
		## pack
		table = Table()
		table.set_border_width(5)
		table.set_row_spacings(5)
		table.set_col_spacings(5)
		
		table.attach(lbl_name, 0, 3, 0, 1, EXPAND|FILL, FILL)
		table.attach(self.entry_name, 1, 3, 1, 2, EXPAND|FILL, FILL)
		table.attach(lbl_commands, 0, 3, 2, 3, EXPAND|FILL, FILL)
		table.attach(lbl_info, 1, 3, 3, 4, EXPAND|FILL, FILL)
		table.attach(self.cmb_command, 1, 2, 4, 5, EXPAND|FILL, FILL)
		table.attach(btn_add, 2, 3, 4, 5, FILL, FILL)
		table.attach(scr_commands, 1, 2, 5, 6)
		table.attach(buttons, 2, 3, 5, 6, FILL, FILL)
		table.attach(lbl_view, 0, 3, 6, 7, EXPAND|FILL, FILL)
		table.attach(self.entry_view_command, 1, 3, 7, 8, EXPAND|FILL, FILL)
		table.attach(lbl_accel, 0, 3, 8, 9, EXPAND|FILL, FILL)
		table.attach(lbl_accel_info, 1, 3, 9, 10, EXPAND|FILL, FILL)
		table.attach(self.entry_accel, 1, 3, 10, 11, EXPAND|FILL, FILL)
		
		table.set_col_spacing(0, 15)
		table.set_row_spacing(1, 15)
		table.set_row_spacing(7, 15)
		table.set_row_spacing(9, 15)
		
		self.vbox.add(table)
	
	def __move_down_command(self):
		store, it = self.view_commands.get_selection().get_selected()
		next_it = store.iter_next(it)
		if (next_it):
			store.swap(it, next_it)
		
	def __add_command(self):
		command = self.cmb_command.get_active_text()
		if len(command):
			self.store_commands.append([command])
	
	def __delete_command(self):
		store, it = self.view_commands.get_selection().get_selected()
		if it:
			store.remove(it)
	
	def run(self):
		self.show_all()
		return Dialog.run(self)
	
	def get_profile(self):
		return Profile(self.entry_name.get_text(), [r[0] for r in self.store_commands], self.entry_view_command.get_text(), self.entry_accel.get_text())
	
	def set_profile(self, profile):
		self.entry_name.set_text(profile.name)
		
		self.store_commands.clear()
		for c in profile.commands:
			self.store_commands.append([c])
			
		self.entry_view_command.set_text(profile.view_command)
		self.entry_accel.set_text(profile.accel)
		
		if profile.name:
			self.set_title("Configure Profile %s" % profile.name)
		else:
			self.set_title("Create Profile")
		
