class SyntaxCheckerMessage:
	def __init__(self, line, column, length, kind, message):
		self.line = int(line)
		self.column = int(column)
		self.length = int(length)
		self.kind = kind
		self.message = message
	
	def __str__(self):
		return "L %s, C %s (%s) : %s '%s'" % (self.line, self.column, self.length, self.kind, self.message)

class SyntaxChecker:
	def __init__(self):
		import re
		
		self.pattern = re.compile(";(?P<l>\d+),(?P<c>\d+),(?P<d>\d+),(?P<k>[a-zA-Z]+),(?P<m>[^;]+);")
		self.messages = []
		self.tmp_filename = None

	def check_file(self, filename):
		import os
	
		# Format: line,column,length,type,message
		command = r'chktex -f ";%l,%c,%d,%k,%m;" --quiet ' + filename
		output = os.popen(command, "r").read()
		print "###\n" + output + "\n###\n"
		self.messages = []
		
		for match in self.pattern.finditer(output):
			m = SyntaxCheckerMessage(match.group("l"), match.group("c"), match.group("d"), match.group("k"), match.group("m"))
			self.messages.append(m)
		
	def check_string(self, string):
		if not self.tmp_filename:
			import tempfile
			
			handle, self.tmp_filename = tempfile.mkstemp()

		f = open(self.tmp_filename, "w")
		f.write(string)
		f.close()
		
		self.check_file(self.tmp_filename)
	
	def cleanup(self):
		if self.tmp_filename:
			import os
			
			os.unlink(self.tmp_filename)
